<div align="center">
  <img src="https://github.com/lucianolorenti/ceruleo/blob/main/docs/images/cerulean.png?raw=true"><br>
</div>

# CeRULEo
-----------------


# CeRULEo: Comprehensive utilitiEs for Remaining Useful Life Estimation methOds

[![Coverage Status](https://coveralls.io/repos/github/lucianolorenti/ceruleo/badge.svg?branch=main)](https://coveralls.io/github/lucianolorenti/ceruleo?branch=main)
[![Documentation](https://img.shields.io/badge/documentation-dev-brightgreen)](https://lucianolorenti.github.io/ceruleo/)

## What is it?

**CeRULeo** is a Python package that provides a flexible environment designed to make working with predictive maintenance task both easy and intuitive. 


# Installation
It is recommended to use pip  for installation. Please make sure the latest version is installed:

```bash
pip install ceruleo            # normal install
pip install --upgrade ceruleo  # or update if needed
```

Alternatively, you could clone and install it from the sources:

```bash
git clone https://github.com/lucianolorenti/ceruleo.git
cd ceruleo
pip install .
```






 Made with <3 @   <a href="https://www.dei.unipd.it/">  
         <img alt="University of Padova" src="https://github.com/lucianolorenti/ceruleo/blob/main/docs/images/unipd_logo.png?raw=true" width=100 />
      </a>

